@@ -16,7 +16,7 @@ namespace ximc
 
 	public static class Version
 	{
-		public const String version = "2.14.20";
+		public const String version = "2.14.23";
 	};
 
 /*
@@ -690,7 +690,7 @@ namespace ximc
 		public int WindingCurrentC;
 		public uint Pot;
 		public uint Joy;
-		public int DutyCycle;
+		public int AveragedPowerRatio;
 	};
 
 	[StructLayout(LayoutKind.Sequential, CharSet=CharSet.Ansi)]
